@@ -204,7 +204,7 @@ def install(
         try:
             with open(f"{backplane['default_context_dir']}/.env", "w") as writer:
                 writer.write(
-                    f"BACKPLANE_DOMAIN={domain}\nBACKPLANE_ENVIRONMENT={backplane['environment']}\nBACKPLANE_MAIL={mail}"
+                    f"BACKPLANE_DOMAIN={domain}\nBACKPLANE_ENVIRONMENT={environment}\nBACKPLANE_MAIL={mail}"
                 )
 
         except Exception as e:
